Module bridge

Module bridge 

Bridge between text-document snapshot types and text-typeset layout params.

Converts FlowSnapshot, BlockSnapshot, TextFormat, etc. into BlockLayoutParams, FragmentParams, TableLayoutParams, etc.

Structs

FlowElements
Converted flow elements, ordered by their position in the flow.

Functions

convert_block
convert_flow
Convert a FlowSnapshot into layout params that can be fed to the Typesetter.
convert_frame
convert_table