pub fn convert_flow(flow: &FlowSnapshot) -> FlowElementsExpand description
Convert a FlowSnapshot into layout params that can be fed to the Typesetter.
pub fn convert_flow(flow: &FlowSnapshot) -> FlowElementsConvert a FlowSnapshot into layout params that can be fed to the Typesetter.