Module resolve

Module resolve 

Structs

ResolvedFont
A resolved font face with all parameters needed for shaping and rasterization.

Functions

find_fallback_font
Find a fallback font that has the given character.
font_has_glyph
Check if a font has a glyph for the given character. Used for glyph fallback -trying other registered fonts when the primary font doesn’t cover a character.
resolve_font
Resolve a font from text formatting parameters.