Module paragraph

Module paragraph 

Structs

Hyphenator
Everything line wrapping needs to hyphenate: the pre-shaped hyphen glyph to append at a break and the ISO 639-1 language for the dictionary. Passed as Some only when hyphenation is enabled.

Enums

Alignment
Text alignment within a line.

Functions

break_into_lines
Break shaped runs into lines that fit within available_width.