pub fn layout_table(
registry: &FontRegistry,
params: &TableLayoutParams,
available_width: f32,
) -> TableLayoutExpand description
Lay out a table: distribute column widths, lay out cell contents, compute row heights.
pub fn layout_table(
registry: &FontRegistry,
params: &TableLayoutParams,
available_width: f32,
) -> TableLayoutLay out a table: distribute column widths, lay out cell contents, compute row heights.