GlyphAtlas

Struct GlyphAtlas 

pub struct GlyphAtlas {
    pub allocator: BucketedAtlasAllocator,
    pub pixels: Vec<u8>,
    pub width: u32,
    pub height: u32,
    pub dirty: bool,
}

Fields

allocator: BucketedAtlasAllocatorpixels: Vec<u8>width: u32height: u32dirty: bool

Implementations

Source

impl GlyphAtlas

pub fn new() -> Self

pub fn allocate(&mut self, width: u32, height: u32) -> Option<Allocation>

pub fn deallocate(&mut self, id: AllocId)

pub fn blit_rgba(&mut self, x: u32, y: u32, w: u32, h: u32, data: &[u8])

Blit RGBA pixel data into the atlas at the given position.

pub fn blit_mask(&mut self, x: u32, y: u32, w: u32, h: u32, data: &[u8])

Blit a single-channel alpha mask into the atlas as white RGBA.