FlowLayout

Struct FlowLayout 

pub struct FlowLayout {
    pub blocks: HashMap<usize, BlockLayout>,
    pub tables: HashMap<usize, TableLayout>,
    pub frames: HashMap<usize, FrameLayout>,
    pub flow_order: Vec<FlowItem>,
    pub content_height: f32,
    pub viewport_width: f32,
    pub viewport_height: f32,
    pub cached_max_content_width: f32,
}

Fields

blocks: HashMap<usize, BlockLayout>tables: HashMap<usize, TableLayout>frames: HashMap<usize, FrameLayout>flow_order: Vec<FlowItem>content_height: f32viewport_width: f32viewport_height: f32cached_max_content_width: f32

Implementations

Source

impl FlowLayout

pub fn new() -> Self

pub fn add_table( &mut self, registry: &FontRegistry, params: &TableLayoutParams, available_width: f32, )

Add a table to the flow at the current y position.

pub fn add_frame( &mut self, registry: &FontRegistry, params: &FrameLayoutParams, available_width: f32, )

Add a frame to the flow.

  • Inline: placed in normal flow, advances content_height.
  • FloatLeft: placed at current y, x=0. Does not advance content_height (surrounding content wraps around it).
  • FloatRight: placed at current y, x=available_width - frame_width.
  • Absolute: placed at (margin_left, margin_top) from document origin. Does not affect flow at all.
pub fn clear(&mut self)

Clear all layout state. Call before rebuilding from a new FlowSnapshot.

pub fn add_block( &mut self, registry: &FontRegistry, params: &BlockLayoutParams, available_width: f32, )

Add a single block to the flow at the current y position.

pub fn layout_blocks( &mut self, registry: &FontRegistry, block_params: Vec<BlockLayoutParams>, available_width: f32, )

Lay out a sequence of blocks vertically.

pub fn relayout_block( &mut self, registry: &FontRegistry, params: &BlockLayoutParams, available_width: f32, )

Update a single block’s layout and shift subsequent blocks if the position or height changed.

If the block’s top margin changed, its y position is recomputed using margin collapsing with the previous block. Subsequent items are shifted by the resulting delta.