Module table

Module table 

Structs

CellLayout
CellLayoutParams
Parameters for a single table cell.
TableLayout
Computed layout for an entire table.
TableLayoutParams
Parameters for a table, extracted from text-document’s TableSnapshot.

Functions

generate_table_decorations
Generate border and background decoration rects for a top-level table.
generate_table_decorations_at
Generate border and background decoration rects for a table whose origin is shifted by (offset_x, offset_y) — a table nested inside a frame (e.g. a blockquote), where the offsets are the frame’s content origin.
layout_table
Lay out a table: distribute column widths, lay out cell contents, compute row heights.